Skip to contents

Returns metadata for all parameters required by the odin model and observation model. Defaults here are aligned to the defaults in `inst/odin/cholera_model.R`

Usage

chlaa_parameter_info()

Value

A data.frame with columns: name, default, units, description, source.