Derive an anticipatory action trigger time from a simulation
Source:R/scenario_builder.R
chlaa_trigger_time_from_sim.RdFinds the first time where an aggregated incidence stream reaches or exceeds a threshold.
R/scenario_builder.R
chlaa_trigger_time_from_sim.RdFinds the first time where an aggregated incidence stream reaches or exceeds a threshold.