Returns metadata for all parameters required by the odin model and observation model. Defaults here are aligned to the defaults in `inst/odin/cholera_model.R`
Returns metadata for all parameters required by the odin model and observation model. Defaults here are aligned to the defaults in `inst/odin/cholera_model.R`